@@ -9,7 +9,7 @@
 
 var debug = false;
 var g_Map;
-var g_UrlJsonFile = '/lua/get_geo_hosts.lua';
+var g_UrlJsonFile = url_prefix+'/lua/get_geo_hosts.lua';
 var g_InfoWindowMarker = new google.maps.InfoWindow();
 var g_InfowindowPolyline = new google.maps.InfoWindow();
 
