@@ -8,5 +8,10 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 require "lua_utils"
 require "alert_utils"
 
+if (ntop.isPro()) then
+  package.path = dirs.installdir .. "/pro/scripts/callbacks/?.lua;" .. package.path
+  require("hourly")
+end
+
 -- Scan "hour" alerts
 scanAlerts("hour")
