@@ -6,8 +6,9 @@ dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 require "lua_utils"
 
-sendHTTPHeader('text/html; charset=iso-8859-1')
+sendHTTPHeader('application/json')
 
+if(haveAdminPrivileges()) then
 currentPage     = _GET["currentPage"]
 perPage         = _GET["perPage"]
 sortColumn      = _GET["sortColumn"]
@@ -76,9 +77,12 @@ for _key, _value in pairsByKeys(vals, funct) do
 	 print ("  \"column_username\"  : \"" .. key .. "\", ")
 	 print ("  \"column_full_name\" : \"" .. value["full_name"] .. "\", ")
 	 print ("  \"column_group\"     : \"" .. value["group"] .. "\", ")
-	 print ("  \"column_edit\"      : \"<a href='#password_dialog' role='button' class='add-on' data-toggle='modal' id='password_btn_" .. key .. "'><span class='label label-info'>Set Password</span></a><script> $('#password_btn_" .. key .. "').on('mouseenter', function() { $('#password_dialog_title').text('" .. key .. "'); $('#password_dialog_username').val('" .. key .. "'); }); </script> ")
-	 print ("<a href='#delete_user_dialog' role='button' class='add-on' data-toggle='modal' id='delete_btn_" .. key .. "'><span class='label label-danger'>Delete</span></a><script> $('#delete_btn_" .. key .. "').on('mouseenter', function() { delete_user_alert.warning('Are you sure you want to delete " .. key .. "?'); $('#delete_dialog_username').val('" .. key .. "'); }); </script>\"")
-	 print ("}")
+	 print ("  \"column_edit\"      : \"<a href='#password_dialog' data-toggle='modal' onclick='return(reset_pwd_dialog(\\\"".. key.."\\\"));'><span class='label label-info'>Manage</span></a> ")
+
+  if(key ~= "admin") then
+	    print ("<a href='#delete_user_dialog' role='button' class='add-on' data-toggle='modal' id='delete_btn_" .. key .. "'><span class='label label-danger'>Delete</span></a><script> $('#delete_btn_" .. key .. "').on('mouseenter', function() { delete_user_alert.warning('Are you sure you want to delete " .. key .. "?'); $('#delete_dialog_username').val('" .. key .. "'); }); </script>")
+	 end
+	 print ("\"}")
 	 num = num + 1
       end
    end
@@ -100,3 +104,4 @@ end
 print ("\"sort\" : [ [ \"" .. sortColumn .. "\", \"" .. sortOrder .."\" ] ],\n")
 
 print ("\"totalRows\" : " .. total .. " \n}")
+end
\ No newline at end of file
