@@ -1,5 +1,5 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -11,7 +11,7 @@ sendHTTPHeader('application/json')
 
 if(_GET["csrf"] ~= nil) then
 
-interface.find(ifname)
+interface.select(ifname)
 if((_GET["hostIP"] ~= nil) and (_GET["hostIP"] ~= "")) then
    vlan = 0
    if ((_GET["hostVlan"] ~= nil) and (_GET["hostIP"] ~= "")) then
