@@ -1,19 +1,18 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
-require "sqlite_utils"
 
 sendHTTPHeader('text/html; charset=iso-8859-1')
 local debug = false
 local debug_process = false -- Show flow processed information
 
-interface.find(ifname)
-ifstats = interface.getStats()
+interface.select(ifname)
+ifstats = aggregateInterfaceStats(interface.getStats())
 -- printGETParameters(_GET)
 
 
@@ -27,23 +26,23 @@ host_info   = url2hostinfo(_GET)
 port        = _GET["port"]
 application = _GET["application"]
 network_id  = _GET["network_id"]
+vhost       = _GET["vhost"]
 
 -- Host comparison parameters
-aggregation = _GET["aggregation"]
 key = _GET["key"]
 
 -- System host parameters
-hosts = _GET["hosts"]
-user = _GET["user"]
-host = _GET["host"]
-pid = tonumber(_GET["pid"])
-name = _GET["name"]
-
-sqlite = _GET["sqlite"]
+hosts  = _GET["hosts"]
+user   = _GET["user"]
+host   = _GET["host"]
+pid    = tonumber(_GET["pid"])
+name   = _GET["name"]
 
 -- Get from redis the throughput type bps or pps
 throughput_type = getThroughputType()
 
+prefs = ntop.getPrefs()
+
 if(network_id ~= nil) then
    network_id = tonumber(network_id)
 end
@@ -51,8 +50,7 @@ end
 if ((sortColumn == nil) or (sortColumn == "column_"))then
   sortColumn = getDefaultTableSort("flows")
 else
-  if ((aggregated == nil) and (sortColumn ~= "column_")
-    and (sortColumn ~= "")) then  
+   if((sortColumn ~= "column_") and (sortColumn ~= "")) then  
     tablePreferences("sort_flows",sortColumn)
   end
 end
@@ -60,13 +58,11 @@ end
 if(sortOrder == nil) then
   sortOrder = getDefaultTableSortOrder("flows")
 else
-  if ((aggregated == nil) and (sortColumn ~= "column_")
-    and (sortColumn ~= "")) then   
+  if ((sortColumn ~= "column_") and (sortColumn ~= "")) then   
     tablePreferences("sort_order_flows",sortOrder) 
   end
 end
 
-
 if(currentPage == nil) then
    currentPage = 1
 else
@@ -89,26 +85,8 @@ if (all ~= nil) then
    currentPage = 0
 end
 
-interface.find(ifname)
-
-if (sqlite == nil) then
-   flows_stats = interface.getFlowsInfo(host)
-else
-   -- Init some parameters
-   to_skip = 0
-   offsetPage = currentPage - 1
-
-   -- Create and exe query
-   query = "SELECT * FROM flows LIMIT "..perPage.." OFFSET "..(perPage*offsetPage)
-   Sqlite:execQuery(sqlite, query)
-
-   -- Get flows in a correct format
-   flows_stats = Sqlite:getFlows()
-   -- tprint(flows_stats)
-   rows_number = Sqlite:getRowsNumber()
-   -- Set default values if the query is empty
-   if (flows_stats == nil) then flows_stats = {} end
-end
+interface.select(ifname)
+flows_stats = interface.getFlowsInfo(host)
 
 print ("{ \"currentPage\" : " .. currentPage .. ",\n \"data\" : [\n")
 total = 0
@@ -126,16 +104,11 @@ if (host ~= nil) then
    num_host_list = 1
 end
 
--- Prepare aggregation
-if ((aggregation ~= nil) and (key ~= nil)) then
-   if (aggregation == "ndpi") then application = key end
-   if (aggregation == "l4proto") then l4proto = key end
-   if (aggregation == "port") then port = tonumber(key) end
-end
-
 vals = {}
 num = 0
 
+if(flows_stats == nil) then flows_stats = { } end
+
 for key, value in pairs(flows_stats) do
    -- print(key.."\n")
    if (debug) then io.write("==================\n")end
@@ -144,8 +117,19 @@ for key, value in pairs(flows_stats) do
    client_process = 0
    server_process = 0
 
-   if (debug) then io.write("Cli:"..flows_stats[key]["cli.ip"].."\t")end
-   if (debug) then io.write("Srv:"..flows_stats[key]["srv.ip"].."\n")end
+   if (debug) then io.write("Cli:"..flows_stats[key]["cli.ip"].."\t") end
+   if (debug) then io.write("Srv:"..flows_stats[key]["srv.ip"].."\n") end
+
+  
+   if(vhost ~= nil) then
+      if((flows_stats[key]["cli.host"] ~= vhost) 
+      and (flows_stats[key]["srv.host"] ~= vhost)
+   and (flows_stats[key]["http.server_name"] ~= vhost)
+   and (flows_stats[key]["dns.last_query"] ~= vhost)) then
+	 process = false
+      end
+   end
+   
 
    if(network_id ~= nil) then
       process = process and ((flows_stats[key]["cli.network_id"] == network_id) or (flows_stats[key]["srv.network_id"] == network_id))
@@ -155,7 +139,7 @@ for key, value in pairs(flows_stats) do
    if(l4proto ~= nil) then
       process = process and (flows_stats[key]["proto.l4"] == l4proto)
    end
-   if (debug and (not process)) then io.write("Stop L4\n")end
+   if (debug and (not process)) then io.write("Stop L4\n") end
 
    ---------------- USER ----------------
    if(user ~= nil) then
@@ -234,7 +218,7 @@ for key, value in pairs(flows_stats) do
 
    ---------------- APP ----------------
    if(application ~= nil) then
-      process = process and (flows_stats[key]["proto.ndpi"] == application)
+      process = process and (string.ends(flows_stats[key]["proto.ndpi"], application))
    end
    if (debug and (not process)) then io.write("Stop ndpi\n")end
 
@@ -257,7 +241,6 @@ for key, value in pairs(flows_stats) do
       process = process and (flows_stats[key]["vlan"] == host_info["vlan"])
 
       else
-
       cli_num = findStringArray(flows_stats[key]["cli.ip"],host_list)
       srv_num = findStringArray(flows_stats[key]["srv.ip"],host_list)
 
@@ -275,10 +258,22 @@ for key, value in pairs(flows_stats) do
       end
    end
 
-if (debug and (not process)) then io.write("Stop Host\n")end
-
-
+   if (debug and (not process)) then io.write("Stop Host\n")end
+   
+   info = ""
+   if(flows_stats[key]["dns.last_query"] ~= nil) then 
+      info = shortenString(flows_stats[key]["dns.last_query"])
+      elseif(flows_stats[key]["http.last_url"] ~= nil) then
+      info = shortenString(flows_stats[key]["http.last_url"])
+      elseif(flows_stats[key]["ssl.certificate"] ~= nil) then
+      info = shortenString(flows_stats[key]["ssl.certificate"])
+   end
 
+   flows_stats[key]["info"] = info	
+   if(flows_stats[key]["profile"] ~= nil) then 
+      flows_stats[key]["info"] = "<span class='label label-primary'>"..flows_stats[key]["profile"].."</span> "..info
+   end
+   
    ---------------- TABLE SORTING ----------------
    if(process) then
       if (debug_process) then io.write("Flow Processing\n")end
@@ -297,6 +292,8 @@ if (debug and (not process)) then io.write("Stop Host\n")end
    vkey = flows_stats[key]["vlan"]+postfix
    elseif(sortColumn == "column_bytes_last") then
    vkey = flows_stats[key]["bytes.last"]+postfix
+   elseif(sortColumn == "column_info") then
+   vkey = info .. postfix
    elseif(sortColumn == "column_ndpi") then
    vkey = flows_stats[key]["proto.ndpi"]..postfix
    elseif(sortColumn == "column_server_process") then
@@ -311,10 +308,6 @@ if (debug and (not process)) then io.write("Stop Host\n")end
    else
       vkey = postfix
    end
-   elseif(sortColumn == "column_category") then
-   c = flows_stats[key]["category"]
-   if(c == nil) then c = "" end
-     vkey = c..postfix
    elseif(sortColumn == "column_duration") then
    vkey = flows_stats[key]["duration"]+postfix
    elseif(sortColumn == "column_thpt") then
@@ -363,14 +356,23 @@ for _key, _value in pairsByKeys(vals, funct) do
    srv_tooltip = ""
    cli_tooltip = ""
 
-   srv_name = flowinfo2hostname(value, "srv", ifstats.iface_vlan)
-   cli_name = flowinfo2hostname(value, "cli", ifstats.iface_vlan)
+   srv_name = flowinfo2hostname(value, "srv", ifstats.vlan)
+   cli_name = flowinfo2hostname(value, "cli", ifstats.vlan)
 
    if(cli_name == nil) then cli_name = "???" end
    if(srv_name == nil) then srv_name = "???" end
 
-   src_key="<A HREF='/lua/host_details.lua?" .. hostinfo2url(value,"cli").. "' data-toggle='tooltip' title='" ..cli_tooltip.. "' >".. abbreviateString(cli_name, 20)
-   if(value["cli.systemhost"] == true) then src_key = src_key .. "&nbsp;<i class='fa fa-flag'></i>" end
+   if((value["tcp.nw_latency.client"] ~= nil) and (value["tcp.nw_latency.client"] > 0)) then
+      cli_tooltip = "client nw latency: "..string.format("%.3f", value["tcp.nw_latency.client"]).." ms"
+   end
+
+   if((value["tcp.nw_latency.server"] ~= nil) and (value["tcp.nw_latency.server"] > 0)) then
+      srv_tooltip = "server nw latency: "..string.format("%.3f", value["tcp.nw_latency.server"]).." ms"
+   end
+
+   if(value["cli.allowed_host"]) then
+      src_key="<A HREF='"..ntop.getHttpPrefix().."/lua/host_details.lua?" .. hostinfo2url(value,"cli").. "' data-toggle='tooltip' title='" ..cli_tooltip.. "' >".. abbreviateString(cli_name, 20)
+      if(value["cli.systemhost"] == true) then src_key = src_key .. "&nbsp;<i class='fa fa-flag'></i>" end
 
    -- Flow username
    i, j = nil
@@ -385,37 +387,40 @@ for _key, _value in pairsByKeys(vals, funct) do
    src_key = src_key .. "</A>"
 
    if(value["cli.port"] > 0) then
-      src_port=":<A HREF='/lua/port_details.lua?port=" .. value["cli.port"] .. "'>"..value["cli.port"].."</A>"
+      src_port=":<A HREF='"..ntop.getHttpPrefix().."/lua/port_details.lua?proto=".. value["proto.l4"].. "&port=" .. value["cli.port"] .. "'>"..ntop.getservbyport(value["cli.port"], string.lower(value["proto.l4"])).."</A>"
          else
       src_port=""
          end
+   else			    
+     src_key = abbreviateString(cli_name, 20)
+     src_port=":"..value["cli.port"]
+   end     
 
-   dst_key="<A HREF='/lua/host_details.lua?".. hostinfo2url(value,"srv").. "' data-toggle='tooltip' title='" ..srv_tooltip.. "' >".. abbreviateString(srv_name, 20)
+   if(value["srv.allowed_host"]) then
+   dst_key="<A HREF='"..ntop.getHttpPrefix().."/lua/host_details.lua?".. hostinfo2url(value,"srv").. "' data-toggle='tooltip' title='" ..srv_tooltip.. "' >".. abbreviateString(srv_name, 20)
    if(value["srv.systemhost"] == true) then dst_key = dst_key .. "&nbsp;<i class='fa fa-flag'></i>" end
    dst_key = dst_key .. "</A>"
 
    if(value["srv.port"] > 0) then
-      dst_port=":<A HREF='/lua/port_details.lua?port=" .. value["srv.port"] .. "'>"..value["srv.port"].."</A>"
+      dst_port=":<A HREF='"..ntop.getHttpPrefix().."/lua/port_details.lua?proto=".. value["proto.l4"].. "&port=" .. value["srv.port"] .. "'>"..ntop.getservbyport(value["srv.port"], string.lower(value["proto.l4"])).."</A>"
          else
       dst_port=""
          end
+  else			    
+     dst_key = abbreviateString(srv_name, 20)
+     dst_port=":"..value["srv.port"]
+   end     
 
    print ("{ \"key\" : \"" .. key..'\"')
 
    descr=cli_name..":"..value["cli.port"].." &lt;-&gt; "..srv_name..":"..value["srv.port"]
-   print (", \"column_key\" : \"<A HREF='/lua/flow_details.lua?flow_key=" .. key .. "&label=" .. descr)
-   if (sqlite ~= nil) then
-      print ("&sqlite="..sqlite.."&ID="..value["ID"])
-   end
+   print (", \"column_key\" : \"<A HREF='"..ntop.getHttpPrefix().."/lua/flow_details.lua?flow_key=" .. key .. "&label=" .. descr)
    print ("'><span class='label label-info'>Info</span></A>")
    print ("\", \"column_client\" : \"" .. src_key)
 
-
    info = interface.getHostInfo(value["cli.ip"])
    if(info ~= nil) then
-      if((info["country"] ~= nil) and (info["country"] ~= "")) then
-         print(" <img src='/img/blank.gif' class='flag flag-".. string.lower(info["country"]) .."'> ")
-      end
+      print(getFlag(info["country"]))
    end
 
    print(src_port)
@@ -424,9 +429,7 @@ for _key, _value in pairsByKeys(vals, funct) do
 
    info = interface.getHostInfo(value["srv.ip"])
    if(info ~= nil) then
-      if((info["country"] ~= nil) and (info["country"] ~= "")) then
-         print(" <img src='/img/blank.gif' class='flag flag-".. string.lower(info["country"]) .."'> ")
-      end
+      print(getFlag(info["country"]))
    end
 
    print(dst_port)
@@ -437,19 +440,30 @@ for _key, _value in pairsByKeys(vals, funct) do
       print("\", \"column_vlan\" : \"\"")
    end
 
-   if(value["category"] ~= nil) then print (", \"column_category\" : \"" .. getCategory(value["category"])) else print (",") end
-   -- if (debug) then io.write(value["category"].."[" .. getCategory(value["category"]).. "]\n")   end
-   print ("\"column_proto_l4\" : \"" .. value["proto.l4"])
-   print ("\", \"column_ndpi\" : \"" .. getApplicationLabel(value["proto.ndpi"]))
+   -- if(value["category"] ~= nil) then print (", \"column_category\" : \"" .. value["category"] .. "\", ") else print (",") end
+   print (", \"column_proto_l4\" : \"")
+
+   if(value["tcp.seq_problems"] == true) then
+      print("<font color=#B94A48>"..value["proto.l4"].."</font>")
+   else
+      print(value["proto.l4"])
+   end
+
+   app = getApplicationLabel(value["proto.ndpi"])
+   if(value["verdict.pass"] == false) then
+      app = "<strike>"..app.."</strike>"
+   end
+   print ("\", \"column_ndpi\" : \"<A HREF=".. ntop.getHttpPrefix().."/lua/hosts_stats.lua?protocol=" .. value["proto.ndpi"] ..">"..app.." " .. formatBreed(value["proto.ndpi_breed"]) .."</A>")
+
    if(value["client_process"] ~= nil) then
       print ("\", \"column_client_process\" : \"")
-      print("<A HREF=/lua/get_process_info.lua?pid=".. value["client_process"]["pid"] .."&name="..value["client_process"]["name"].."&host="..value["cli.ip"]..">" .. processColor(value["client_process"]).."</A>")
-      print ("\", \"column_client_user_name\" : \"<A HREF=/lua/get_user_info.lua?user=" .. value["client_process"]["user_name"] .."&host="..value["cli.ip"]..">" .. value["client_process"]["user_name"].."</A>")
+      print("<A HREF="..ntop.getHttpPrefix().."/lua/get_process_info.lua?pid=".. value["client_process"]["pid"] .."&name="..value["client_process"]["name"].."&host="..value["cli.ip"]..">" .. processColor(value["client_process"]).."</A>")
+      print ("\", \"column_client_user_name\" : \"<A HREF="..ntop.getHttpPrefix().."/lua/get_user_info.lua?user=" .. value["client_process"]["user_name"] .."&host="..value["cli.ip"]..">" .. value["client_process"]["user_name"].."</A>")
    end
    if(value["server_process"] ~= nil) then
       print ("\", \"column_server_process\" : \"")
-      print("<A HREF=/lua/get_process_info.lua?pid=".. value["server_process"]["pid"] .."&name="..value["server_process"]["name"].."&host="..value["srv.ip"]..">" .. processColor(value["server_process"]).."</A>")
-      print ("\", \"column_server_user_name\" : \"<A HREF=/lua/get_user_info.lua?user=" .. value["server_process"]["user_name"] .."&host="..value["srv.ip"]..">" .. value["server_process"]["user_name"].."</A>")
+      print("<A HREF="..ntop.getHttpPrefix().."/lua/get_process_info.lua?pid=".. value["server_process"]["pid"] .."&name="..value["server_process"]["name"].."&host="..value["srv.ip"]..">" .. processColor(value["server_process"]).."</A>")
+      print ("\", \"column_server_user_name\" : \"<A HREF="..ntop.getHttpPrefix().."/lua/get_user_info.lua?user=" .. value["server_process"]["user_name"] .."&host="..value["srv.ip"]..">" .. value["server_process"]["user_name"].."</A>")
    end
 
    print ("\", \"column_duration\" : \"" .. secondsToTime(value["duration"]))
@@ -482,10 +496,21 @@ for _key, _value in pairsByKeys(vals, funct) do
    cli2srv = round((value["cli2srv.bytes"] * 100) / value["bytes"], 0)
    print (", \"column_breakdown\" : \"<div class='progress'><div class='progress-bar progress-bar-warning' style='width: " .. cli2srv .."%;'>Client</div><div class='progress-bar progress-bar-info' style='width: " .. (100-cli2srv) .. "%;'>Server</div></div>")
 
-   print ("\" }\n")
-   num = num + 1
+   print ("\", \"column_info\" : \"".. value["info"])
+
+   if(prefs.is_categorization_enabled and (value["info"] ~= "")) then
+      flow = interface.findFlowByKey(tonumber(key))
+      if(flow ~= nil) then value["category"] = flow["category"] end
+      if(value["category"] ~= "") then
+	 print(" ".. getCategoryIcon(value["info"], value["category"]))
       end
    end
+
+   print(" \" }\n")
+   
+   num = num + 1
+end
+   end
 end -- for
 
 print ("\n], \"perPage\" : " .. perPage.. ",\n")
@@ -499,8 +524,4 @@ if(sortOrder == nil) then
 end
 
 print ("\"sort\" : [ [ \"" .. sortColumn .. "\", \"" .. sortOrder .."\" ] ],\n")
-if (sqlite == nil) then
-   print ("\"totalRows\" : " .. total .. " \n}")
-else
-   print ("\"totalRows\" : " .. (Sqlite:getRowsNumber()) .. " \n}")
-end
+print ("\"totalRows\" : " .. total .. " \n}")
