@@ -1,5 +1,5 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -12,7 +12,7 @@ sendHTTPHeader('application/json')
 
 
 host_info = url2hostinfo(_GET)
-interface.find(ifname)
+interface.select(ifname)
 
 print [[
 {"center":[0, 0],
@@ -38,9 +38,7 @@ print [[
 		print('City: '..value["city"])
 	     end
 
-	     if((value["country"] ~= nil) and (value["country"] ~= "")) then
-		print(" <img src='/img/blank.gif' class='flag flag-".. string.lower(value["country"]) .."'>")
-	     end
+	     print(getFlag(value["country"]))
 	     print('",\n')
 
 	     print('"name": "'..key..'"\n')
@@ -58,7 +56,7 @@ print [[
 
     -- Flows with trajectory
 
-    interface.find(ifname)
+    interface.select(ifname)
     peers = interface.getFlowPeers(host_info["host"],host_info["vlan"])
 
     maxval = 0
@@ -90,9 +88,7 @@ print [[
 		print('City: '..values["client.city"])
 	     end
 
-	     if((values["client.country"] ~= nil) and (values["client.country"] ~= "")) then
-		print(" <img src='/img/blank.gif' class='flag flag-".. string.lower(values["client.country"]) .."'>")
-	     end
+	     print(getFlag(values["country"]))
 	     print('",\n')
 
 	     print('"name": "'..values["client"].."@"..values["client.vlan"]..'"\n')
@@ -104,9 +100,7 @@ print [[
 	     if((values["server.city"] ~= nil) and (values["server.city"] ~= "")) then
 		print('City: '..values["server.city"])
 	     end
-	     if((values["server.country"] ~= nil) and (values["server.country"] ~= "")) then
-		print(" <img src='/img/blank.gif' class='flag flag-".. string.lower(values["server.country"]) .."'>")
-	     end
+	     print(getFlag(values["server.country"]))
 	     print('",\n')
 
 	     print('"name": "'..values["server"].."@"..values["client.vlan"]..'"\n')
