@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2014-15-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,17 +7,17 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 
 host_ip = _GET["host"]
 
-interface.find(ifname)
+interface.select(ifname)
 host = interface.getHostInfo(host_ip)
 
 if(host == nil) then
    value = 0
 else
-   value = host["pkts.sent"]+host["pkts.rcvd"]
+   value = host["packets.sent"]+host["packets.rcvd"]
 end
 
 print(' { "value": ' .. value .. ' } ')
\ No newline at end of file
