@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -9,7 +9,7 @@ require "lua_utils"
 
 sendHTTPHeader('application/json')
 
-interface.find(ifname)
+interface.select(ifname)
 hosts_stats = interface.getHostsInfo()
 
 print [[
@@ -38,7 +38,10 @@ for key, value in pairs(hosts_stats) do
    if(val > threshold) then
 
    if(num > 0) then print(",\n") else print("\n") end
-   print("{ \"name\": \"" .. ntop.getResolvedAddress(hosts_stats[key]["ip"]).. "\", \"size\": " .. (hosts_stats[key]["bytes.sent"]+hosts_stats[key]["bytes.rcvd"]).. "} ")
+   res = ntop.getResolvedAddress(key)
+
+   --if(res == nil) then res = "AAA" end
+   print("{ \"name\": \"" .. res .. "\", \"size\": " .. (hosts_stats[key]["bytes.sent"]+hosts_stats[key]["bytes.rcvd"]).. "} ")
    num = num + 1
 
 else
