@@ -1,5 +1,5 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -9,7 +9,7 @@ require "lua_utils"
 
 sendHTTPHeader('text/html; charset=iso-8859-1')
 
-interface.find(ifname)
+interface.select(ifname)
 
 mode = _GET["mode"]
 type = _GET["type"]
@@ -18,7 +18,7 @@ host = interface.getHostInfo(host_info["host"],host_info["vlan"])
 
 
 if(host == nil) then
-   print("<div class=\"alert alert-danger\"><img src=/img/warning.png> This flow cannot be found (expired ?)</div>")
+   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> This flow cannot be found (expired ?)</div>")
 else
 
 if((type == nil) or (type == "size")) then
