@@ -1,5 +1,5 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -12,9 +12,12 @@ local json = require ("dkjson")
 
 host_info = url2hostinfo(_GET)
 
-if(host_info["host"] ~= nil) then
-   interface.find(ifname)
-   host = interface.getHostInfo(host_info["host"],host_info["vlan"]) 
+if((host_info ~= nil) and (host_info["host"] ~= nil)) then
+   interface.select(ifname)
+   host = interface.getHostInfo(host_info["host"], host_info["vlan"]) 
+   if(host == nil) then
+      host = "{}"
+   end
 else
    host = "{}"
 end
