@@ -1,5 +1,5 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -13,7 +13,7 @@ ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
 active_page = "hosts"
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
-interface.find(ifname)
+interface.select(ifname)
 hosts_stats = interface.getHostsInfo()
 num = 0
 for key, value in pairs(hosts_stats) do
@@ -66,7 +66,9 @@ var treemap = d3.layout.treemap()
        .style("left", margin.left + "px")
        .style("top", margin.top + "px");
 
-       d3.json("/lua/get_treemap.lua", function(error, root) {
+       d3.json("]]
+print (ntop.getHttpPrefix())
+print [[/lua/get_treemap.lua", function(error, root) {
 				   var node = div.datum(root).selectAll(".node")
 				   .data(treemap.nodes)
 				   .enter().append("div")
@@ -77,7 +79,9 @@ var treemap = d3.layout.treemap()
 						      if(d.children) return(null);
 						   else {
 							 if(d.name != "Other Hosts") {
-							    return("<A HREF=\"/lua/host_details.lua?host="+d.name+"\">"+d.name+"</A>");
+							    return("<A HREF=\"]]
+print (ntop.getHttpPrefix())
+print [[/lua/host_details.lua?host="+d.name+"\">"+d.name+"</A>");
 							 } else 
 							 return(d.name);
 						      }
@@ -108,7 +112,7 @@ var treemap = d3.layout.treemap()
 
 ]]
 else 
-print("<div class=\"alert alert-danger\"><img src=/img/warning.png> No results found</div>")
+   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> No results found</div>")
 end
 
-dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
\ No newline at end of file
+dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
