@@ -1,5 +1,5 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -9,8 +9,8 @@ require "lua_utils"
 
 sendHTTPHeader('text/html; charset=iso-8859-1')
 
-interface.find(ifname)
-ifstats = interface.getStats()
+interface.select(ifname)
+ifstats = aggregateInterfaceStats(interface.getStats())
 
 type = _GET["type"]
 
