@@ -1,8 +1,8 @@
 --
--- (C) 2014 - ntop.org
+-- (C) 2014-15 - ntop.org
 --
 
-ifstats = interface.getStats()
+_ifstats = aggregateInterfaceStats(interface.getStats())
 
 print [[
 
@@ -10,10 +10,6 @@ print [[
 
 <style>
 
-#chart {
-  height: 380px;
-}
-
 .node rect {
   cursor: move;
   fill-opacity: .9;
@@ -37,20 +33,16 @@ print [[
 
 </style>
 
-<div id="chart"></div>
-<script src="/js/sankey.js"></script>
+<div id="chart" style="margin-left: auto; margin-right: auto;"></div>
+<script src="]] print(ntop.getHttpPrefix()) print[[/js/sankey.js"></script>
 
 <script>
 ]]
 -- Create javascript vlan boolean variable
-if (ifstats.iface_vlan) then print("var iface_vlan = true;") else print("var iface_vlan = false;") end
+if (_ifstats.iface_vlan) then print("var iface_vlan = true;") else print("var iface_vlan = false;") end
 
 print [[
 
-var margin = {top: 1, right: 1, bottom: 6, left: 1},
-    width = 800 - margin.left - margin.right,
-    height = 400 - margin.top - margin.bottom;
-
 function b2s(bytes) {
       var sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB'];
       if (bytes == 0) return 'n/a';
@@ -59,6 +51,14 @@ function b2s(bytes) {
    };
 
 function sankey() {
+
+  var w = $("#chart").width();
+  var h = window.innerHeight / 2;
+
+  var margin = {top: 1, right: 10, bottom: 1, left: 10},
+      width = w - margin.left - margin.right,
+      height = h - margin.top - margin.bottom;
+
   var formatNumber = d3.format(",.0f"),
     format = function(sent, rcvd) { return "[sent: "+b2s(sent)+", rcvd: "+b2s(rcvd)+"]"; },
     color = d3.scale.category20();
@@ -69,18 +69,18 @@ active_sankey = "host"
 local debug = false
 
 if(_GET["sprobe"] ~= nil) then
-   print('d3.json("/lua/sprobe_hosts_data.lua"');
+   print('d3.json("'..ntop.getHttpPrefix()..'/lua/sprobe_hosts_data.lua"');
 else
    if(_GET["host"] ~= nil) then
-      print('d3.json("/lua/iface_flows_sankey.lua?ifname='..ifname..'&' ..hostinfo2url(host_info).. '"')
+      print('d3.json("'..ntop.getHttpPrefix()..'/lua/iface_flows_sankey.lua?ifname='..ifname..'&' ..hostinfo2url(host_info).. '"')
    elseif((_GET["hosts"] ~= nil) and (_GET["aggregation"] ~= nil)) then
-      print('d3.json("/lua/hosts_comparison_sankey.lua?ifname='..ifname..'&'..'hosts='.._GET["hosts"] .. '&aggregation='.._GET["aggregation"] ..'"')
+      print('d3.json("'..ntop.getHttpPrefix()..'/lua/hosts_comparison_sankey.lua?ifname='..ifname..'&'..'hosts='.._GET["hosts"] .. '&aggregation='.._GET["aggregation"] ..'"')
       active_sankey = "comparison"
    elseif(_GET["hosts"] ~= nil) then
-      print('d3.json("/lua/hosts_comparison_sankey.lua?ifname='..ifname..'&'..'hosts='.._GET["hosts"] ..'"')
+      print('d3.json("'..ntop.getHttpPrefix()..'/lua/hosts_comparison_sankey.lua?ifname='..ifname..'&'..'hosts='.._GET["hosts"] ..'"')
       active_sankey = "comparison"
    else
-      print('d3.json("/lua/iface_flows_sankey.lua"')
+      print('d3.json("'..ntop.getHttpPrefix()..'/lua/iface_flows_sankey.lua"')
    end
 end
 
@@ -134,7 +134,9 @@ print [[
 	  .style("stroke", function(d){ return d.color = colorlink(d); })
 	  .sort(function(a, b) { return b.dy - a.dy; })
     .on("dblclick", function(d) {
-        url_ref = "/lua/hosts_comparison.lua?hosts="+escape(d.source.host);
+        url_ref = "]]
+print (ntop.getHttpPrefix())
+print [[/lua/hosts_comparison.lua?hosts="+escape(d.source.host);
 
         if(iface_vlan )
           url_ref  += "@"+escape(d.source.vlan);
@@ -176,7 +178,9 @@ print [[
 	  .attr("height", 12)
 	  .attr("width", 150)
 	  .style("opacity", "0")
-	  .on("click", function(d) { window.location.href = "/lua/host_details.lua?host="+escape(d.host)+"@"+escape(d.vlan);  })
+	  .on("click", function(d) { window.location.href = "]]
+print (ntop.getHttpPrefix())
+print [[/lua/host_details.lua?host="+escape(d.host)+"@"+escape(d.vlan);  })
 	  .attr("transform", null)
 	  .filter(function(d) { return d.x < width / 2; })
 	  .attr("x", 4 + sankey.nodeWidth())
@@ -198,12 +202,12 @@ print [[
 
 elseif(active_sankey == "comparison") then
 
-ifstats = interface.getStats()
+_ifstats = aggregateInterfaceStats(interface.getStats())
 
-if(ifstats.iface_sprobe) then
-   url = "/lua/sflows_stats.lua?"
+if(_ifstats.iface_sprobe) then
+   url = ntop.getHttpPrefix().."/lua/sflows_stats.lua?"
 else
-   url = "/lua/flows_stats.lua?"
+   url = ntop.getHttpPrefix().."/lua/flows_stats.lua?"
 end
 
 print [[
@@ -298,8 +302,3 @@ var sankey_interval = window.setInterval(sankey, 5000);
 
 </script>]]
 
-
-
-print [[
-
-]]
\ No newline at end of file
