@@ -1,12 +1,19 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
+if(ntop.isPro()) then
+   print(ntop.httpRedirect(ntop.getHttpPrefix().."/lua/pro/dashboard.lua"))
+   return
+end
+
+
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 -- io.write ("Session:".._SESSION["session"].."\n")
 require "lua_utils"
 
+
 sendHTTPHeader('text/html; charset=iso-8859-1')
 
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
@@ -16,8 +23,8 @@ ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
 active_page = "home"
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
-interface.find(ifname)
-ifstats = interface.getStats()
+interface.select(ifname)
+ifstats = aggregateInterfaceStats(interface.getStats())
 is_loopback = isLoopback(ifname)
 iface_id = interface.name2id(ifname)
 
@@ -47,7 +54,7 @@ if(page == nil) then
 end
 
 
-if((ifstats ~= nil) and (ifstats.stats_packets > 0)) then
+if((ifstats ~= nil) and (ifstats.packets > 0)) then
 -- Print tabbed header
 
    print('<nav class="navbar navbar-default" role="navigation">\n\t<div class="navbar-collapse collapse">\n\t<ul class="nav navbar-nav">\n')
@@ -56,25 +63,23 @@ if((ifstats ~= nil) and (ifstats.stats_packets > 0)) then
 
    if(not(is_loopback)) then
       if(page == "TopFlowTalkers") then active=' class="active"' else active = "" end
-      print('<li'..active..'><a href="/?page=TopFlowTalkers">Talkers</a></li>\n')
+      print('<li'..active..'><a href="'..ntop.getHttpPrefix()..'/?page=TopFlowTalkers">Talkers</a></li>\n')
    end
 
    if((page == "TopHosts")) then active=' class="active"' else active = "" end
-   print('<li'..active..'><a href="/?page=TopHosts">Hosts</a></li>\n')
+   print('<li'..active..'><a href="'..ntop.getHttpPrefix()..'/?page=TopHosts">Hosts</a></li>\n')
 
    if((page == "TopPorts")) then active=' class="active"' else active = "" end
-   print('<li'..active..'><a href="/?page=TopPorts">Ports</a></li>\n')
+   print('<li'..active..'><a href="'..ntop.getHttpPrefix()..'/?page=TopPorts">Ports</a></li>\n')
 
    if((page == "TopApplications")) then active=' class="active"' else active = "" end
-   print('<li'..active..'><a href="/?page=TopApplications">Applications</a></li>\n')
+   print('<li'..active..'><a href="'..ntop.getHttpPrefix()..'/?page=TopApplications">Applications</a></li>\n')
 
    if(not(is_loopback)) then
       if((page == "TopASNs")) then active=' class="active"' else active = "" end
-      print('<li'..active..'><a href="/?page=TopASNs">ASNs</a></li>\n')
-      if not (interface.isHistoricalInterface(iface_id)) then
-        if((page == "TopFlowSenders")) then active=' class="active"' else active = "" end
-        print('<li'..active..'><a href="/?page=TopFlowSenders">Senders</a></li>\n')
-      end
+      print('<li'..active..'><a href="'..ntop.getHttpPrefix()..'/?page=TopASNs">ASNs</a></li>\n')
+      if((page == "TopFlowSenders")) then active=' class="active"' else active = "" end
+      print('<li'..active..'><a href="'..ntop.getHttpPrefix()..'/?page=TopFlowSenders">Senders</a></li>\n')
    end
 
    print('</ul>\n\t</div>\n\t</nav>\n')
@@ -104,11 +109,11 @@ end
 print [[<span class="caret"></span></button>
   <ul class="dropdown-menu ">
 ]]
-print('<li style="text-align: left;"> <a href="?refresh=5000" >5 Seconds</a></li>\n')
-print('<li style="text-align: left;"> <a href="?refresh=10000" >10 Seconds</a></li>\n')
-print('<li style="text-align: left;"> <a href="?refresh=30000" >30 Seconds</a></li>\n')
-print('<li style="text-align: left;"> <a href="?refresh=60000" >1 Minute</a></li>\n')
-print('<li style="text-align: left;"> <a href="?refresh=0" >Never</a></li>\n')
+print('<li style="text-align: left;"> <a href="'..ntop.getHttpPrefix()..'?refresh=5000" >5 Seconds</a></li>\n')
+print('<li style="text-align: left;"> <a href="'..ntop.getHttpPrefix()..'?refresh=10000" >10 Seconds</a></li>\n')
+print('<li style="text-align: left;"> <a href="'..ntop.getHttpPrefix()..'?refresh=30000" >30 Seconds</a></li>\n')
+print('<li style="text-align: left;"> <a href="'..ntop.getHttpPrefix()..'?refresh=60000" >1 Minute</a></li>\n')
+print('<li style="text-align: left;"> <a href="'..ntop.getHttpPrefix()..'?refresh=0" >Never</a></li>\n')
 print [[
   </ul>
 </div><!-- /btn-group -->
@@ -177,37 +182,7 @@ print [[
   --ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/index_top.inc")
   -- ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/index_bottom.inc")
 else
-
-  if (interface.isHistoricalInterface(iface_id)) then
-    print [[
-    <br>
-    <div class="alert alert-info">
-      <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
-      <strong>Welcome to the Historical Interface</strong><br>In order to use this interface you must specify, via the  <a href="/lua/if_stats.lua?if_name=Historical&page=config_historical">configuration page</a>, the interface, for which you want to load the historical data, and the time interval to be loaded.
-    </div>
-
-    ]]
-
-  else
-     print("<div class=\"alert alert-warning\">No packet has been received yet on interface " .. getHumanReadableInterfaceName(ifname) .. ".<p>Please wait <span id='countdown'></span> seconds until this page reloads.</div> <script type=\"text/JavaScript\">(function countdown(remaining) { if(remaining <= 0) location.reload(true); document.getElementById('countdown').innerHTML = remaining;  setTimeout(function(){ countdown(remaining - 1); }, 1000);})(10);</script>")
-
-  end
-end
-
-info = ntop.getInfo()
-
-if(page == "TopFlowTalkers") then
-   rsp = ntop.httpGet("www.ntop.org", "/ntopng.version")
-
-
-   version_elems = split(info["version"], " ");
-
-   stable_version = version2int(rsp)
-   this_version   = version2int(version_elems[1])
-
-   if(stable_version > this_version) then
-      print("<p><div class=\"alert alert-warning\"><font color=red><i class=\"fa fa-cloud-download fa-lg\"></i> A new ntopng version (v." .. rsp .. ") is available for <A HREF=http://www.ntop.org>download</A>: please upgrade.</font></div></p>")
-   end
+   print("<div class=\"alert alert-warning\">No packet has been received yet on interface " .. getHumanReadableInterfaceName(ifname) .. ".<p>Please wait <span id='countdown'></span> seconds until this page reloads.</div> <script type=\"text/JavaScript\">(function countdown(remaining) { if(remaining <= 0) location.reload(true); document.getElementById('countdown').innerHTML = remaining;  setTimeout(function(){ countdown(remaining - 1); }, 1000);})(10);</script>")
 end
 
 dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
\ No newline at end of file
