@@ -1,5 +1,5 @@
 --
--- (C) 2013-14 - ntop.org
+-- (C) 2013-15 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -12,7 +12,7 @@ sendHTTPHeader('text/html; charset=iso-8859-1')
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/menu.inc")
 
-print('<div class="alert alert-danger"><img src=/img/warning.png> Page not found</div>')
+print('<div class="alert alert-danger"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> Page not found</div>')
 
 print ("<center><H4>Unable to find URL <i>")
 
